# Generated by Django 2.2.4 on 2019-11-05 17:04

from django.db import migrations, models
import djmongo.dataimport.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='DataImport',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('file1', models.FileField(upload_to=djmongo.dataimport.models.update_import_filename, verbose_name='File to be Imported')),
                ('input_format', models.CharField(choices=[('csv', 'Comma Separated Value (.csv)')], default='csv', max_length=3)),
                ('delete_collection_before_import', models.BooleanField(default=False)),
                ('status', models.CharField(default='New', editable=False, max_length=10, verbose_name='Status')),
                ('response', models.TextField(blank=True, default='', max_length=2048, verbose_name='Response')),
                ('database_name', models.CharField(max_length=256)),
                ('collection_name', models.CharField(max_length=256)),
                ('creation_date', models.DateField(auto_now_add=True)),
            ],
            options={
                'ordering': ('-creation_date',),
                'get_latest_by': 'creation_date',
            },
        ),
    ]
