{% extends "djmongo/console/base.html" %}
{% block Content %}

{% load i18n %}


<div class="container">
    <br><br>
    <div class="row">
        <div class="col-lg-12">
            <div class="jumbotron">
              <h1>Welcome to Djmongo</h1>
              <p>Djmongo provides a web user interface for MongoDB and RESTful API creation.
                <a href="https://github.com/videntity/django-djmongo">
                    Please see the documentation</a> for more details.
              </p>

              <p> <a class="btn btn-primary btn-lg" href="{% url 'djmongo_show_dbs'%}" role="button">
              Continue to the Console</a></p>
            </div>
        </div>  
    </div>
</div>
    {% endblock %}
