
def run_public_delete_api(request, database_name, collection_name, slug, output_type):
    pass


def run_httpauth_delete_api(request, database_name, collection_name, slug, output_type):
    pass


def run_ipauth_delete_api(request, database_name, collection_name, slug, output_type):
    pass
