{% load static %}
<div class="footer-wrapper">
        <div class="row text-center" > 
  <div class="col-lg-12">
           
        <div>
           <hr>
           <em>Djmongo Community Edition is free open source software under the
           <a href="https://github.com/videntity/django-djmongo/blob/master/LICENSE.txt">GPL v2</a> license.</a> <br>
           For support and advanced features <em><a href="mailto:sales@videntity.com">get a commercial license.</a></em>
           </em><br>
        </div>
        <div>
           <a href="http://www.videntity.com" title="Videntity" target=""_blank>
           <img src="{% static 'djmongo/img/layout/videntity-logo.png' %}"></a> &copy; 
        </div>

        <div>
        
        </div>



    </div>
  </div>
</div>

