<!DOCTYPE html>
<html lang="en">
 <head>
        <title>
        Search Results generated @ {{ timestamp }}
        </title>
  </head>
  <body>
      <h1>Seach Results  @ {{ timestamp }}</h1>
      
      <table border=1>
        {% for row in rows %}
        <tr>
            {% for field in row%}
            <td>{{field}}</td>
            {% endfor %}
        </tr>
        {% endfor %}
    </table>
      

  </body>

</html>