{% load i18n %}
 <nav class="navbar navbar-default navbar-fixed-top" role="navigation">
      <div class="container">
        <div class="navbar-header">
          <button type="button" class="navbar-toggle" data-toggle="collapse" data-target=".navbar-ex1-collapse">
            <span class="sr-only">Toggle navigation</span>
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
          </button>
          <a class="navbar-brand" href="{% url 'djmongo_show_dbs' %}">Djmongo</a>
        </div>

        <!-- Collect the nav links, forms, and other content for toggling -->
        <div class="collapse navbar-collapse navbar-ex1-collapse">
          <ul class="nav navbar-nav navbar-right">
            {% if user.is_authenticated %}

            <!-- <li><a href="{% url 'djmongo_show_dbs' %}">Databases</a></li> -->
            <!-- <li><a href="{% url 'djmongo_api_list' %}">APIs</a></li>-->

            
            <li class="dropdown">
             <a href="#" class="dropdown-toggle" data-toggle="dropdown">Global Actions <b class="caret"></b></a>
              <ul class="dropdown-menu">
                <li><a href="{% url 'djmongo_create_new_database' %}">
                    <i class="fa fa-database"></i> Create Database</a>
                </li>
                
               <li><a href="{% url 'djmongo_import_csv' %}">
                    <i class="fa fa-arrow-right"></i> Import Data into a New Database</a>
                </li>
                
                
                </li>                                
                                
                <li><a href="{% url 'admin:auth_user_changelist' %}">
                        <i class="fa fa-user"></i> Users</a>
                </li>
                
                <li><a href="{% url 'admin:auth_group_changelist' %}">
                        <i class="fa fa-users"></i> </i> Groups</a>
                </li>
                
        
              </ul>
            </li>
            {% endif %} 
            
           <li><a target="_blank" href="http://videntity.github.io/django-djmongo/">Help</a></li>
           
              {% if user.is_authenticated %}
                 <li><a href="{% url 'djmongo_logout' %}">Logout</a></li>
              {% else %}
                <li><a href="{% url 'djmongo_logout' %}">Login</a></li>
            {% endif %}
          </ul>
        </div><!-- /.navbar-collapse -->
      </div><!-- /.container -->
    </nav>
