{% extends "djmongo/console/base.html" %}
{% load i18n %}
{% load widget_tweaks %}
{% block Content %}
{% load bootstrap %}



    <div class="container">

      <div class="row">

        <div class="col-lg-12">
          <h1 class="page-header">{{name}} <small>{{subname}}</small></h1>
        </div>

      </div>
	  
	  <div class="row">

        <div class="col-lg-12">
          * Required Fields
        </div>

      </div>
	  

 
 
<div class="row">
  
    <div class="col-lg-8">
      
      <form class="well" method="post" action="" enctype="multipart/form-data">
          {% csrf_token %}
          {{ form|bootstrap }}
       {% load widget_tweaks %}


	<input type="submit" class="btn btn-primary btn-large"  value="{% trans 'Continue' %}" />
	&nbsp;&nbsp;<input type="reset" class="btn  btn-large"  value="Reset" />
	
	<br><br>
	<a href="javascript:history.go(-1)">{% trans "Go Back" %}</a>
      
      </form>
    </div>

        </div>

      </div>

    </div><!-- /.container -->

  

{% endblock %}


