{% extends "djmongo/console/base.html" %}
{% block pretitle %}Results as HTML Table{% endblock %}
{% block extra_head %}

{% endblock %}
{% block Content %}
    
    <h1>Seach Results  @ {{ timestamp }}</h1>
    <table class="table table-condensed table-bordered">
        
        
        
        {% for row in rows %}
        <tr>
            {% for field in row%}
            <td>{{field}}</td>
            {% endfor %}
        </tr>
        {% endfor %}
    </table>


  
{% endblock %}