<meta charset="utf-8">
<meta http-equiv="X-UA-Compatible" content="IE=edge">
<meta name="viewport" content="width=device-width, initial-scale=1">
<meta name="description" content="djmongo | A MongoDB Toolkit for Django"/>
<meta name="author" content="Alan Viars">
{% load static %}
<link href="{% static 'djmongo/console/img/favicon.png' %}" rel="shortcut icon" type="image/x-icon" />

<!-- Custom Fonts -->
    <link href="{% static 'djmongo/console/modern-business/font-awesome-4.1.0/css/font-awesome.min.css' %}" rel="stylesheet" type="text/css">

<meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta name="description" content="">


    <!-- Bootstrap core CSS -->
   <link href="{% static 'djmongo/console/modern-business/css/bootstrap.css' %}" rel="stylesheet">
   <link href="{% static 'djmongo/console/modern-business/css/modern-business.css' %}" rel="stylesheet">


    <!-- Add custom CSS here -->

