<div class="row">
        <div class="col-lg-12">
            <div id="messages">
                    {% if messages %}
                      {% for message in messages %}
                        <div class="alert alert-{{message.tags}}">
                          <a class="close" data-dismiss="alert">×</a>
                          {{message}}
                        </div>
                      {% endfor %}
                    {% endif %}
            </div>
        </div>
</div>